@@ -1,7 +1,8 @@
 # coding=utf-8
 """
-Django related tasks
---------------------
+Django related tasks.
+=====================
+
 """
 
 import os
