@@ -1,4 +1,8 @@
-"""Git related utilities."""
+"""
+Git related utilities.
+======================
+
+"""
 import os
 from fabric.api import fastprint, run, cd, task, env
 from fabric.colors import red, cyan, green
@@ -12,7 +16,7 @@ from .common import setup_env
 def update_git_checkout(code_path, url, repo_alias, branch='master', tag=None):
     """Make sure there is a read only git checkout.
 
-    :param code_path: Path to where the repo should be.
+    :param code_path: Path to where the repo should be checked out.
     :type code_path: str
 
     :param url: Complete http url for cloning/checking out the repo.
@@ -30,7 +34,7 @@ def update_git_checkout(code_path, url, repo_alias, branch='master', tag=None):
 
     To run e.g.::
 
-        fab -H 188.40.123.80:8697 remote update_git_checkout
+        fab -H foo:1234 remote update_git_checkout
 
     """
     fastprint(cyan('Updating git checkout.\n'))
